@@ -8,9 +8,6 @@ import logging
 import time
 import math
 import websocket
-import ndg-httpsclient
-import pyopenssl
-import pyasn1
 
 
 class scratch:
